import {AppBar, Box, Toolbar, Typography, Button, IconButton, Menu, MenuItem} from '@mui/material';
import HomeIcon from '@mui/icons-material/Home';
import {NavLink} from "react-router-dom";
import {MAIN, REGISTER, LOGIN} from "../../../constants/routes";
import {useSelector} from "react-redux";
import {useState} from 'react';

const AppToolbar = () => {
    const user = useSelector(({usersState}) => usersState.user);

    const [anchorEl, setAnchorEl] = useState(null);

    const handleClick = e => {
       setAnchorEl(e.currentTarget);
    };

    const handleClose = () => {
        setAnchorEl(null);
    };

    return (
        <Box sx={{ flexGrow: 1 }}>
            <AppBar position="static">
                <Toolbar>
                    <IconButton
                        size="large"
                        edge="start"
                        color="inherit"
                        aria-label="menu"
                        sx={{ mr: 2 }}
                        component={NavLink}
                        to={MAIN}
                    >
                        <HomeIcon />
                    </IconButton>
                    <Typography variant="h6" component="div" sx={{ flexGrow: 1 }}>
                        Shop
                    </Typography>
                    {
                        user
                            ? <>
                                <Button
                                    aria-controls="simple-menu"
                                    aria-haspopup={true}
                                    onClick={handleClick}
                                    color="inherit"
                                >
                                    Hello, {user.username}
                                </Button>
                                <Menu
                                    open={!!anchorEl}
                                    anchorEl={anchorEl}
                                    onClose={handleClose}
                                    keepMounted
                                >
                                    <MenuItem>Profile</MenuItem>
                                    <MenuItem>My account</MenuItem>
                                    <MenuItem>Logout</MenuItem>
                                </Menu>
                            </>
                            : <>
                                <Button color="inherit" component={NavLink} to={REGISTER}>Sign up</Button>
                                <Button color="inherit" component={NavLink} to={LOGIN}>Sign In</Button>
                            </>
                    }
                    </Toolbar>
            </AppBar>
        </Box>
    );
};

export default AppToolbar;
